                .LF     rnd16tst.lst
;------------------------------------------------------------------------
;
;  rnd16tst.asm
;
;  Simple test program for 16 bit pseudo random number generator
;
;  Author : San Bergmans
;  Source : www.sbprojects.com
;  Date   : 20-12-2005
;
;------------------------------------------------------------------------
;
;  This is not a very spectacular program. It simply counts the
;  repetition rate of an 8 bit pseudo random number generator.
;  This pseudo random number generator is used in the GUESS program.
;
;  The program simply starts with a seed of 0 and counts the number of
;  generated pseudo random numbers before a 0 is generated again.
;  The answer from this program (00000H) proves that the pseudo random
;  number generator repeats after the promised 65536 calls. Please note
;  that we're actually ignoring the carry out of the 16 bit counter.
;  Thus the answer should actually have been 010000H), but who cares.
;
;------------------------------------------------------------------------

                .CR     Z80             Yeah! We're programming the Z80!
                .OR     01800H          RAM starts here, so are we
                .TF     rnd16tst.hex,HEX Create a plain hex dump file

;------------------------------------------------------------------------
;  Monitor routines
;------------------------------------------------------------------------

SCAN            .EQ     005FEH          Scan display until a key pressed
HEX7SG          .EQ     00678H          Convert 2 hex digits to 7-segment

;------------------------------------------------------------------------
;  RND16TEST
;------------------------------------------------------------------------

RND16TEST       LD      IX,DSP_BFFR     Set pointer to display buffer
                LD      BC,0            Clear repeat counter
                LD      HL,0            Initialize seed

.LOOP           LD      D,L             Calculate pseudo random number
                LD      E,6
                SRL     D
                RR      E
                ADD     HL,DE

                INC     BC              Increment iteration counter

                LD      A,L             Back at 0?
                OR      A,H
                JR      NZ,.LOOP        Not yet!

                LD      A,C             Get counter
                LD      HL,DSP_BFFR     Convert to two 7-segment digits
                CALL    HEX7SG
                LD      A,B
                CALL    HEX7SG
.4EVER          CALL    SCAN            Show this until a key is pressed
                RST     030H            Return to monitor
                JR      RND16TEST       Restart to program if GO pressed

;------------------------------------------------------------------------
;  RAM variables
;------------------------------------------------------------------------

DSP_BFFR        .DA     #0,#0,#0,#0,#0,#0

;------------------------------------------------------------------------

                .LI     OFF
